@@ -6,22 +6,22 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
+package Software::LicenseMoreUtils::LGPL_2;
+$Software::LicenseMoreUtils::LGPL_2::VERSION = '1.006';
 use strict;
 use warnings;
-package Software::LicenseMoreUtils::LGPL_2;
-$Software::LicenseMoreUtils::LGPL_2::VERSION = '1.003';
+
 use base 'Software::License';
 # ABSTRACT: GNU Library General Public License, Version 2
 
-sub name { 'The GNU Library General Public License, Version 2, June 1991' }
-sub url  { 'http://www.gnu.org/licenses/old-licenses/lgpl-2.0.html' }
-sub meta_name  { 'lgpl' }
-sub meta2_name { 'lgpl_2' }
+sub name { return 'The GNU Library General Public License, Version 2, June 1991' }
+sub url  { return 'http://www.gnu.org/licenses/old-licenses/lgpl-2.0.html' }
+sub meta_name  { return 'lgpl' }
+sub meta2_name { return 'lgpl_2' }
+sub spdx_expression  { return 'LGPL-2.0-only' }
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -32,12 +32,25 @@ Software::LicenseMoreUtils::LGPL_2 - GNU Library General Public License, Version
 
 =head1 VERSION
 
-version 1.003
+version 1.006
 
 =head1 NAME
 
 Software::LicenseMoreUtils::LGPL_2 - GNU Library General Public License, Version 2
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Dominique Dumont.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
 __DATA__
 __LICENSE__
                   GNU LIBRARY GENERAL PUBLIC LICENSE
@@ -443,7 +456,7 @@ conditions either of that version or of any later version published by
 the Free Software Foundation.  If the Library does not specify a
 license version number, you may choose any version ever published by
 the Free Software Foundation.
-
+
   14. If you wish to incorporate parts of the Library into other free
 programs whose distribution conditions are incompatible with these,
 write to the author to ask for permission.  For software which is
@@ -521,16 +534,3 @@ necessary.  Here is a sample; alter the names:
   Ty Coon, President of Vice
 
 That's all there is to it!
-
-=head1 AUTHOR
-
-Dominique Dumont
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2018 by Dominique Dumont.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
