@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package Software::LicenseMoreUtils::LicenseWithSummary;
-$Software::LicenseMoreUtils::LicenseWithSummary::VERSION = '1.003';
+$Software::LicenseMoreUtils::LicenseWithSummary::VERSION = '1.006';
 # ABSTRACT: Software::License with a summary
 
 use strict;
@@ -23,8 +23,8 @@ use Text::Template;
 our $AUTOLOAD;
 
 # map location of distro file (like /etc/redhat_release) to distro.
-# must match a <distro>_summaries.yml file in the same directory at
-# this file
+# must match a <distro>_summaries.yml file in the directory containing
+# this Perl module file
 my %path_to_distro = (
     '/etc/debian_version' => 'debian',
 );
@@ -47,7 +47,7 @@ sub new {
         or_later => $args->{or_later},
     };
 
-    bless $self, $class;
+    return bless $self, $class;
 }
 
 sub distribution { return $distro }
@@ -90,10 +90,15 @@ sub summary_or_text {
 }
 
 sub AUTOLOAD {
-    my $self = shift;
+    my ($self, @args) = @_;
     my $lic = $self->{license};
     my ($sub) = ($AUTOLOAD =~ /(\w+)$/);
-    return $lic->$sub(@_) if ($lic and $sub ne 'DESTROY');
+    if ($lic and $sub ne 'DESTROY') {
+        return $lic->$sub(@args);
+    }
+    else {
+        return;
+    }
 }
 
 1;
@@ -110,7 +115,7 @@ Software::LicenseMoreUtils::LicenseWithSummary - Software::License with a summar
 
 =head1 VERSION
 
-version 1.003
+version 1.006
 
 =head1 SYNOPSIS
 
@@ -133,7 +138,9 @@ Returns the license summary, or an empty string.
 
 =head2 summary_or_text
 
-Returns the license summary or the full text of the license.
+Returns the license summary or the full text of the license. Like
+L<Software::License/fulltext>, this method returns also the copyright
+notice (if available).
 
 =head2 distribution
 
